-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------
function MiningPost:StartActivity()
   	print("START! -- MiningPost:StartActivity()!");
	
	self.SweepZone = SceneMan.Scene:GetArea("SweepZone"); -- Zone to clear out of enemies
	self.DummyDropZone = SceneMan.Scene:GetArea("DummyDropZone"); -- Dummy dropship zone
	self.CoalitionDropZone = SceneMan.Scene:GetArea("CoalitionDropZone"); -- Coalition dropship zone
	self.DummyBombing = SceneMan.Scene:GetArea("DummyBombing"); -- Dummy rocklet bombing zone
	
	self.DummyFiringPointUpper = Vector(1815 , 363);
	self.DummyFiringPointLower = Vector(1780 , 458);

	self.CoalitionFiringPointUpper = Vector(2185 , 366);
	self.CoalitionFiringPointLower = Vector(2212 , 458);

	self.braindead = {};
	self.AssignedBrains = {};
	self.MOIDLimit = 220;
    
    self.GenericTimer = Timer();

	
	self.DifficultyCoeff = 0.0;
	self.Difficulties = { CAKE = 0 , EASY = 1 , NORMAL = 2 , HARD = 3 , NUTS = 4 , TRUNUTS = 5};
	self.DifficltyLevel = self.Difficulties.CAKE;
	
	-- Here we're tuning difficulty coefficients depending on selected difficulty level
	-- Don't know the actual values so I'm just guessing
	-- So now original gameplay can be achieved at HARD level
	-- Nuts!
	if self.Difficulty == 100 then
		self.DifficultyCoeff = 0.5;
		self.DifficltyLevel = self.Difficulties.TRUNUTS;
	end

	-- Nuts
	if self.Difficulty < 99 then
		self.DifficultyCoeff = 0.8;
		self.DifficltyLevel = self.Difficulties.NUTS;
	end
	
	-- Hard
	if self.Difficulty < 80 then
		self.DifficultyCoeff = 1.0;
		self.DifficltyLevel = self.Difficulties.HARD;
	end
	
	-- Normal
	if self.Difficulty < 60 then
		self.DifficultyCoeff = 1.25;
		self.DifficltyLevel = self.Difficulties.NORMAL;
	end

	-- Easy
	if self.Difficulty < 40 then
		self.DifficultyCoeff = 1.50;
		self.DifficltyLevel = self.Difficulties.EASY;
	end
	
	-- Cake
	if self.Difficulty < 20 then
		self.DifficultyCoeff = 2.0;
		self.DifficltyLevel = self.Difficulties.CAKE;
	end
	
   	self.BomberSpawnTimer = Timer();
	self.BomberSpawnInterval = 15000 * self.DifficultyCoeff;
	self.BombersEnabled = false;

   	self.DropshipSpawnTimer = Timer();
	self.DropshipSpawnInterval = 15000 * self.DifficultyCoeff;
	self.DropshipsEnabled = false;

   	self.RockletSpawnTimer = Timer();
	self.RockletSpawnInterval = 15000 * self.DifficultyCoeff;
	self.RockletsEnabled = false;
	
   	self.DummySpawnTimer = Timer();
	self.DummySpawnInterval = 10000 * self.DifficultyCoeff;
	
   	self.CoalitionSpawnTimer = Timer();
	self.CoalitionSpawnInterval = 10000 * self.DifficultyCoeff;
	
    self.WeaponSets = { Light = 0 , Heavy = 1 , Extreme = 2};
    self.FightPhase = { NOFIGHT = 0 , DIGGOLD = 1 , WARFARE = 2 , WARFARE2 = 3 , WARFARE3 = 4 , EVACUATE = 5};
    self.CurrentFightPhase = self.FightPhase.NOFIGHT;

	self.Left2RightPath = {Vector(2000 , 10) , Vector(2300 , 20) , Vector(2600, 60) , Vector(3000 , 90) , 
						   Vector(3300, 120) , Vector (3600 , 150) , Vector (3850, 180)};


	self.Right2LeftPath = {Vector(2800 , 20) , Vector(2500 , 20) , Vector(2200 , 30) , Vector(1900, 60) , Vector(1600 , 90) , 
						   Vector(1300, 120) , Vector (1000 , 150) , Vector (700, 180) , Vector (400 , 210) , 
						   Vector (150 , 210)};

    
    self.RoninGrenades = { "Pineapple Grenade", "Molotov Cocktail" , "Stick Grenade"};
    
    self.CoalitionLightWeapons = {"Shotgun" , "Sniper Rifle" , "Compact Assault Rifle" , "Flamer"};
    self.CoalitionHeavyWeapons = {"Mauler Shotgun" , "Heavy Sniper Rifle" , "Assault Rifle" , "Napalm Flamer"};
    self.CoalitionExtremeWeapons = {"Uber Cannon" , "Auto Cannon" , "Rocket Launcher" , "Heavy Sniper Rifle"};
    self.CoalitionSecondaryWeapons = {"Auto Pistol" , "Compact Assault Rifle"};

    self.DummyLightWeapons = {"Rail Pistol" , "Nailgun" , "Blaster" , "Sniper Rifle"};
    self.DummyHeavyWeapons = {"Sniper Rifle" , "Repeater" , "Nailer Cannon" , "Destroyer Cannon" , "Annihiliator"};
    self.DummyExtremeWeapons = {"Sniper Rifle" , "Repeater" , "Grenade Launcher" , "Annihiliator"};
    self.DummySecondaryWeapons = {"Nailgun" , "Blaster"};
	
	-- Generic timing and money parameters
	-- No money and alive reinforcements availabe for player according to the plot
	self.PlayerGold = 500; -- Player starting credits
	self.TotalGold = 11500; -- We will calculate winning gold amount for those players who prefer playing with much gold
	self.GoldToTriggerWarfare = self.PlayerGold + 500;
	self.GoldToPhase2 = self.PlayerGold + 2500 + math.random(500);
	self.GoldToPhase3 = self.PlayerGold + 3500 + math.random(500);
	self.GoldToWin = self.PlayerGold + self.TotalGold;
	
	-- Ronin squad
	self.Mia = nil;
	self.Dimitry = nil;
	self.Brutus = nil;
	self.Sandra = nil;
	self.Grodon = nil;

	-- Controlled bomber vars
	self.LastVel = Vector(0 , 0);
	self.ControlledShip = nil;
	self.ShipPath = {};
	self.CurrentWaypoint = 1;
	self.ControlledSpeed = 6; -- The higher the speed the more crazy and unpredictable controlled ship will be :)
	
	-- Ronin special abilities countdonwn timer
	self.SpecialAbilitiesTimer = Timer();
	self.SpecialAbilitiesTimer:Reset();
	self.SpecialAbilitiesInterval = 50; -- Time to refresh special abilities

	--"Dig gold" variables
	self.DigGoldMessageInterval = 14000;
	self.DigGoldMessageShowTime = 7000;
	self.DigGoldMessages = {};
	self.DigGoldMessageShown = {};
	
	self.DigGoldMessages[1] = "BE CAREFUL, COALITION PATROLS CAN BE NEAR";
	self.DigGoldMessages[2] = "IT'S CALM AND QUIET. THIS WON'T TAKE LONG";
	self.DigGoldMessages[3] = "SELL UNUSED WEAPONS TO GET MORE GOLD";

	self.DigGoldMessageShown[1] = false;
	self.DigGoldMessageShown[2] = false;
	self.DigGoldMessageShown[3] = false;
	
	-- "Warfare" variables
	self.WarfareMessageInterval = 10000;
	self.WarfareMessageShowTime = 8000;
	self.WarfareMessages = {};
	self.WarfareMessageShown = {};
	
	self.WarfareMessages[1] = "DUMMY FORCES APPROACHING FROM THE EAST";
	self.WarfareMessages[2] = "WE'RE STUCK BETWEEN DUMMIES AND CLONES";
	self.WarfareMessages[3] = "PROTECT MINING BASE AND CONTINUE DIGGING";
	self.WarfareMessages[4] = string.format ("GET %d OZ AND EVACUATE FROM THIS HELL" , self.GoldToWin);

	self.WarfareMessageShown[1] = false;
	self.WarfareMessageShown[2] = false;
	self.WarfareMessageShown[3] = false;
	self.WarfareMessageShown[4] = false;
	
   	-- Set up teams
   	-- Team 2 is always CPU
   	self.CPUTeam = Activity.TEAM_2;
	self.PlayerTeam = Activity.TEAM_1;
	self.RogueTeam = Activity.TEAM_3;
    
   	-- Set up players
    for player = 0, self.PlayerCount - 1 do
        -- Check if we already have a brain assigned
        if not self:GetPlayerBrain(player) then
			self.braindead[player] = false;
			local brain = CreateAHuman("Dafred Brain" , "Mining Post.rte");
			brain.Pos = Vector(650 + player * 30, 700);
			-- brain.Pos = Vector(2000 + player * 30, 200);  -- debug, spawn in bunker
			brain:AddInventoryItem(CreateHDFirearm("Custom M16","Mining Post.rte"));
			brain:AddInventoryItem(CreateHDFirearm("Desert Eagle","Ronin.rte"));
			brain.AIMode = Actor.AIMODE_SENTRY;
			brain.Team = self.PlayerTeam;
			self.AssignedBrains[player] = brain;
            -- Let the spawn into the world, passing ownership
            MovableMan:AddActor(brain);
            -- Set the found brain to be the selected actor at start
            self:SetPlayerBrain(brain, player);
			self:SwitchToActor(brain, player, self:GetTeamOfPlayer(player));
            SceneMan:SetScroll(self:GetPlayerBrain(player).Pos, player);
            self:SetLandingZone(self:GetPlayerBrain(player).Pos, player);
            -- Set the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
            self:SetObservationTarget(self:GetPlayerBrain(player).Pos, player);
        end
    end
    
    -- Spawn ronin squad
	self.Mia = CreateAHuman("Mia" , "Ronin.rte");
	self.Mia.Pos = Vector(520,704);
	self.Mia:AddInventoryItem(CreateHDFirearm("Custom Uzi","Mining Post.rte"));
	self.Mia:AddInventoryItem(CreateHDFirearm("Lady Pistol","Ronin.rte"));
	
	self.Dimitri = CreateAHuman("Dimitri Sniper" , "Mining Post.rte");
	self.Dimitri.Pos = Vector(160,744);
	self.Dimitri:AddInventoryItem(CreateHDFirearm("Custom Sniper Rifle","Mining Post.rte"));
	self.Dimitri:AddInventoryItem(CreateHDFirearm("Glock","Ronin.rte"));
	-- self.Dimitri:AddInventoryItem(CreateHDFirearm("Experimental Laser Rifle X-27" , "Mining Post.rte"));    
	
	self.Brutus = CreateAHuman("Brutus" , "Ronin.rte");
	self.Brutus.Pos = Vector(420,724);
	self.Brutus:AddInventoryItem(CreateHDFirearm("Custom YAK4700","Mining Post.rte"));
	self.Brutus:AddInventoryItem(CreateHDFirearm("Peacemaker","Ronin.rte"));

	self.Sandra = CreateAHuman("Sandra" , "Ronin.rte");
	self.Sandra.Pos = Vector(50,744);
	self.Sandra:AddInventoryItem(CreateHDFirearm("Uzi","Ronin.rte"));
	self.Sandra:AddInventoryItem(CreateHDFirearm("Medikit","Mining Post.rte"));
    
	self.Gordon = CreateAHuman("Gordon" , "Ronin.rte");
	self.Gordon.Pos = Vector(300,724);
	self.Gordon:AddInventoryItem(CreateHDFirearm("Bazooka","Ronin.rte"));
	self.Gordon:AddInventoryItem(CreateHDFirearm("Rifle Long","Ronin.rte"));
   
	self.Mia.Team = self.PlayerTeam;
	self.Dimitri.Team = self.PlayerTeam;
	self.Brutus.Team = self.PlayerTeam;
	self.Sandra.Team = self.PlayerTeam;
	self.Gordon.Team = self.PlayerTeam;
   
	--[[self.Mia.Health = 30; -- Medikit debug with low healths
	self.Dimitri.Health = 30;
	self.Brutus.Health = 30;
	self.Sandra.Health = 30;
	self.Gordon.Health = 30;]]--

    MovableMan:AddActor(self.Mia);
    MovableMan:AddActor(self.Dimitri);
    MovableMan:AddActor(self.Brutus);
    MovableMan:AddActor(self.Sandra);
    MovableMan:AddActor(self.Gordon);
   
    -- Set up AI modes for the Actors that have been added to the scene by the scene definition
    for actor in MovableMan.AddedActors do
		actor.AIMode = Actor.AIMODE_SENTRY;
		
		-- Make two lowest clone start digging
		if actor.Pos.Y > 600 and actor.Team == self.CPUTeam then
			actor.AIMode = Actor.AIMODE_GOTO;
			actor:ClearAIWaypoints();
			if actor.Pos.X < 2020 and actor.Pos.X > 1980 then
				actor:AddAISceneWaypoint(Vector(actor.Pos.X , actor.Pos.Y + 150));
			elseif actor.Pos.X < 2000 then
				actor:AddAISceneWaypoint(Vector(actor.Pos.X - 100 , actor.Pos.Y + 150));
			else
				actor:AddAISceneWaypoint(Vector(actor.Pos.X + 100, actor.Pos.Y + 150));
			end
		end
    end

    -- Set the team's funds.
    self:SetTeamFunds(self.PlayerGold , self.PlayerTeam);

    -- Reset all timers
	self.GenericTimer:Reset();
	self.BomberSpawnTimer:Reset();
	self.DropshipSpawnTimer:Reset();
	self.RockletSpawnTimer:Reset();
	self.CoalitionSpawnTimer:Reset();
	self.DummySpawnTimer:Reset();
	
	-- Cover the scene with fog of war
	SceneMan:MakeAllUnseen(Vector(25, 25), self.PlayerTeam);	
end

-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------
function MiningPost:PauseActivity(pause)
    print("PAUSE! -- DummyAssault:PauseActivity()!");
end

-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------
function MiningPost:EndActivity()
    print("END! -- DummyAssault:EndActivity()!");
end

-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------
function MiningPost:UpdateActivity()
   	-- Clear all objective markers, they get re-added each frame
   	self:ClearObjectivePoints();

	-- self:SkipPhases();  -- Debug only!
	self:DoBrainSelection();
	self:DoSpecialAbilities()
	self:DoGenericShipSpawn();
	self:DoRockletSpawn();
	self:DoControlledShipSpawn();
	self:DoControlShip();
	
	if self.CurrentFightPhase == self.FightPhase.NOFIGHT then
		self:PhaseNoFight();
	elseif self.CurrentFightPhase == self.FightPhase.DIGGOLD then
		self:PhaseDigGold();
	elseif self.CurrentFightPhase == self.FightPhase.WARFARE then
		self:PhaseWarfare();
	elseif self.CurrentFightPhase == self.FightPhase.WARFARE2 then
		self:PhaseWarfare2();
	elseif self.CurrentFightPhase == self.FightPhase.WARFARE3 then
		self:PhaseWarfare3();
	elseif self.CurrentFightPhase == self.FightPhase.EVACUATE then
		self:PhaseEvacuate();
	end
	
	if self.Mia ~= nil and MovableMan:IsActor(self.Mia) then
		if self.Mia.Health < 1 then 
			self.Mia = nil; 
		end
	end

	if self.Dimitri ~= nil and MovableMan:IsActor(self.Dimitri) then
		if self.Dimitri.Health < 1 then 
			self.Dimitri = nil; 
		end
	end

	if self.Brutus ~= nil and MovableMan:IsActor(self.Brutus) then
		if self.Brutus.Health < 1 then 
			self.Brutus = nil; 
		end
	end

	if self.Sandra ~= nil and MovableMan:IsActor(self.Sandra) then
		if self.Sandra.Health < 1 then 
			self.Sandra = nil; 
		end
	end

	if self.Gordon ~= nil and MovableMan:IsActor(self.Gordon) then
		if self.Gordon.Health < 1 then 
			self.Gordon = nil; 
		end
	end
	
	self:YSortObjectivePoints();
end
-----------------------------------------------------------------------------------------
-- Skip Phases
-----------------------------------------------------------------------------------------
function MiningPost:SkipPhases()
	-- Comment unnecessary parts when debuging
	if self.CurrentFightPhase == self.FightPhase.NOFIGHT then
		-- Debug -- Skip No Fight phase
		-- Kill everyone
		for actor in MovableMan.AddedActors do
			if actor.Team == self.CPUTeam then
				actor.Health = -1;
				-- actor:GibThis();
			end
		end
			
		-- Teleport to bunker
		self.Mia.Pos = self.SweepZone:GetRandomPoint();
		self.Dimitri.Pos = self.SweepZone:GetRandomPoint();
		self.Brutus.Pos = self.SweepZone:GetRandomPoint();
		self.Sandra.Pos = self.SweepZone:GetRandomPoint();
		self.Gordon.Pos = self.SweepZone:GetRandomPoint();

		self:AdvanceToDigGold();
	end

	if self.CurrentFightPhase == self.FightPhase.DIGGOLD then
		-- Debug -- Skip Dig gold phase
		self:AdvanceToWarfare();
	end

	if self.CurrentFightPhase == self.FightPhase.WARFARE then
		-- Debug -- Skip weak warfare phase
		self:AdvanceToWarfare2();
	end

	--[[if self.CurrentFightPhase == self.FightPhase.WARFARE2 then
		-- Debug -- Skip heavy warfare
		self:AdvanceToWarfare3();
		
		-- Debug -- Skip extreme warfare
		--self:SetTeamFunds(self.GoldToWin - 10 , self.PlayerTeam);
	end]]--
end
-----------------------------------------------------------------------------------------
-- Brain selection and gameover conditions check
-----------------------------------------------------------------------------------------
function MiningPost:DoBrainSelection()
	if not (self.ActivityState == Activity.OVER) then
		-- Iterate through all human players
		for player = 0, self.PlayerCount - 1 do
			-- The current player's team
			local team = self:GetTeamOfPlayer(player);
	
			-- Make sure the game is not already ending
			-- Check if any player's brain is dead
			local brain = self:GetPlayerBrain(player);
			if not brain or not MovableMan:IsActor(brain) or not brain:HasObjectInGroup("Brains") then
				self:SetPlayerBrain(nil, player);
				-- Try to find a new unasigned brain this player can use instead, or if his old brain entered a craft
				local newBrain = MovableMan:GetUnassignedBrain(team);
				-- Found new brain actor, assign it and keep on truckin'
				if newBrain and self.braindead[player] == false then
					self:SetPlayerBrain(newBrain, player);
					self:SwitchToActor(newBrain, player, team);
				else
					FrameMan:SetScreenText("Commander died!", player, 333, -1, false);
					self.braindead[player] = true;
					
					-- Now see if all brains of self player's team are dead, and if so, end the game
					if not MovableMan:GetClosestBrainActor(team) then
						self.WinnerTeam = self:OtherTeam(team);
						ActivityMan:EndActivity();
					end
				end
			else
				-- Update the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
				self:SetObservationTarget(brain.Pos, player)
			end -- 
		end --for
	-- Game over, show the appropriate messages until a certain time
	elseif not self.GameOverTimer:IsPastSimMS(self.GameOverPeriod) then
		for player = 0, self.PlayerCount - 1 do
			local team = self:GetTeamOfPlayer(player);
			-- TODO: make more appropriate messages here for run out of funds endings
			if team == self.WinnerTeam then
				FrameMan:SetScreenText("Success!", player, 0, -1, false);
			else
				FrameMan:SetScreenText("Commander died!", player, 0, -1, false);
			end
		end
	end
end
-----------------------------------------------------------------------------------------
-- Special abilities
-----------------------------------------------------------------------------------------
function MiningPost:DoSpecialAbilities()
	if self.SpecialAbilitiesTimer:IsPastSimMS(self.SpecialAbilitiesInterval) then
		-- Sandra restores her health
		if self.Sandra ~= nil and MovableMan:IsActor(self.Sandra) then
			if self.Sandra.Health < 100 then
				self.Sandra.Health = self.Sandra.Health + 1
			end
		end
		
		-- Gordon has infinite ronin grenades
		if self.Gordon ~= nil and MovableMan:IsActor(self.Gordon) then
			-- We check Gordon health becuase if he is dying and exploding we can 
			-- accidently spawn grenades somewhere in the air
			if self.Gordon.Health > 20 then
				for i = 1 , #self.RoninGrenades do
					if not self.Gordon:HasObject(self.RoninGrenades[i]) then
						self.Gordon:AddInventoryItem(CreateTDExplosive(self.RoninGrenades[i],"Ronin.rte"));
					end
				end
			end
		end

		self.SpecialAbilitiesTimer:Reset();
	end
end
-----------------------------------------------------------------------------------------
-- Spawn ship
-----------------------------------------------------------------------------------------
function MiningPost:DoGenericShipSpawn()
	if self.BomberSpawnTimer:IsPastSimMS(self.BomberSpawnInterval / 6) and self.DropshipSpawnTimer:IsPastSimMS(self.DropshipSpawnInterval) and MovableMan:GetMOIDCount() <= self.MOIDLimit and self.DropshipsEnabled then
		-- Add dummies and ship
		print("Spawn ship");
		local isdummy = true;
		local dummyactors = 0;
		local coalitionactors = 0;

		-- Determine which snipers to spawn, weakest side gets snipers
		for actor in MovableMan.Actors do
			if actor.Team == self.CPUTeam then 
				coalitionactors = coalitionactors + 1;
			elseif actor.Team == self.RogueTeam then
				dummyactors = dummyactors + 1;
			end
		end
		
		print ("Coalition: ");
		print (coalitionactors);
		print ("Dummies: ");
		print (dummyactors);
		
		if coalitionactors < dummyactors then
			isdummy = false;
			print ("Selected coalition");
		elseif coalitionactors > dummyactors then
			isdummy = true;
			print ("Selected dummies");
		else
			if math.random() < 0.5 then
				isdummy = false;
				print ("Selected coalition by random");
			else
				isdummy = true;
				print ("Selected dummy by random");
			end
		end

		if (self.CurrentFightPhase == self.FightPhase.WARFARE2 or self.CurrentFightPhase == self.FightPhase.WARFARE3) and math.random() < 0.4 then
			-- Spawn ship with snipers trying to take over firing points
			local ship = nil;
			local snipers = {};
			
			if isdummy then
				ship = CreateACDropShip("Drop Ship","Dummy.rte");
				ship.Team = self.RogueTeam;
			else
				ship = CreateACDropShip("Drop Ship MK1","Base.rte");
				ship.Team = self.CPUTeam;
			end
			
			if isdummy then
				for s = 1 , 2 do
					snipers[s] = CreateAHuman("Dummy" , "Dummy.rte");
					
					if self.CurrentFightPhase == self.FightPhase.WARFARE2 then
						snipers[s]:AddInventoryItem(CreateHDFirearm("Sniper Rifle" , "Dummy.rte"));
						snipers[s]:AddInventoryItem(CreateHDFirearm("Blaster" , "Dummy.rte"));
					elseif self.CurrentFightPhase == self.FightPhase.WARFARE3 then
						snipers[s]:AddInventoryItem(CreateHDFirearm("Sniper Rifle" , "Dummy.rte"));
						snipers[s]:AddInventoryItem(CreateHDFirearm("Sniper Rifle" , "Dummy.rte"));
					end
					-- snipers[s]:AddInventoryItem(CreateHDFirearm("Turbo Digger" , "Dummy.rte"));
					
					snipers[s].Team = self.RogueTeam;
					-- Clones go to the right
				end --for

				snipers[1].AIMode = Actor.AIMODE_GOTO;
				snipers[1]:ClearAIWaypoints();
				snipers[1]:AddAISceneWaypoint(self.DummyFiringPointUpper);
				
				snipers[2].AIMode = Actor.AIMODE_GOTO;
				snipers[2]:ClearAIWaypoints();
				snipers[2]:AddAISceneWaypoint(self.DummyFiringPointLower);

				ship:AddInventoryItem(snipers[1]);
				ship:AddInventoryItem(snipers[2]);
			else
				for s = 1 , 2 do
					snipers[s] = CreateAHuman("Soldier Heavy" , "Coalition.rte");
					
					if self.CurrentFightPhase == self.FightPhase.WARFARE2 then
						snipers[s]:AddInventoryItem(CreateHDFirearm("Sniper Rifle" , "Coalition.rte"));
						snipers[s]:AddInventoryItem(CreateHDFirearm("Compact Assault Rifle" , "Coalition.rte"));
					elseif self.CurrentFightPhase == self.FightPhase.WARFARE3 then
						if math.random() < 0.15 then
							snipers[s]:AddInventoryItem(CreateHDFirearm("Experimental Laser Rifle X-27" , "Mining Post.rte"));
						else
							snipers[s]:AddInventoryItem(CreateHDFirearm("Heavy Sniper Rifle" , "Dummy.rte"));
						end
						snipers[s]:AddInventoryItem(CreateHDFirearm("Assault Rifle" , "Coalition.rte"));
					end
					-- snipers[s]:AddInventoryItem(CreateHDFirearm("Pulse Digger" , "Coalition.rte"));
					
					snipers[s].Team = self.CPUTeam;
					-- Clones go to the right
				end --for

				snipers[1].AIMode = Actor.AIMODE_GOTO;
				snipers[1]:ClearAIWaypoints();
				snipers[1]:AddAISceneWaypoint(self.CoalitionFiringPointUpper);
				
				snipers[2].AIMode = Actor.AIMODE_GOTO;
				snipers[2]:ClearAIWaypoints();
				snipers[2]:AddAISceneWaypoint(self.CoalitionFiringPointLower);

				ship:AddInventoryItem(snipers[1]);
				ship:AddInventoryItem(snipers[2]);
			end

			ship.Pos = Vector(self.SweepZone:GetRandomPoint().X, 0);
			ship:SetControllerMode(Controller.CIM_AI, -1);

			MovableMan:AddActor(ship);
		else
			if isdummy then
				local ship = CreateACDropShip("Drop Ship","Dummy.rte");
				local actor = nil;
				
				actor = CreateACrab("Dreadnought");
				actor.Team = self.RogueTeam;
				-- Dummies go to the left
				actor.AIMode = Actor.AIMODE_GOTO;
				actor:ClearAIWaypoints();
				actor:AddAISceneWaypoint(Vector(10 , 744));

				ship:AddInventoryItem(actor);
				-- Select LZ
				ship.Pos = Vector(self.DummyDropZone:GetRandomPoint().X, 0);
				ship.Team = self.RogueTeam;
				ship:SetControllerMode(Controller.CIM_AI, -1);

				MovableMan:AddActor(ship);
			else
				local ship = CreateACDropShip("Drop Ship MK1","Base.rte");
				local actor = nil;
				
				actor = CreateAHuman("Soldier Heavy" , "Coalition.rte");
				if self.CurrentFightPhase == self.FightPhase.WARFARE3 or self.CurrentFightPhase == self.FightPhase.EVACUATE then
					actor:AddInventoryItem(CreateHDFirearm("Experimental Laser Rifle X-27" , "Mining Post.rte"));
				else
					actor:AddInventoryItem(CreateHDFirearm("Heavy Sniper Rifle" , "Coalition.rte"));
				end
				actor:AddInventoryItem(CreateHDFirearm(self.CoalitionSecondaryWeapons[math.random(#self.CoalitionSecondaryWeapons)],"Coalition.rte"));
				actor.Team = self.CPUTeam;
				-- Clones go to the right
				actor.AIMode = Actor.AIMODE_GOTO;
				actor:ClearAIWaypoints();
				actor:AddAISceneWaypoint(Vector(3990 , 744));

				ship:AddInventoryItem(actor);
				-- Select LZ
				ship.Pos = Vector(self.CoalitionDropZone:GetRandomPoint().X, 0);
				ship.Team = self.CPUTeam;
				ship:SetControllerMode(Controller.CIM_AI, -1);

				MovableMan:AddActor(ship);
			end
		end
		self.DropshipSpawnTimer:Reset();
		print("Ship spawn complete");				
	end
end
-----------------------------------------------------------------------------------------
-- Spawn kamikadze rocklet
-----------------------------------------------------------------------------------------
function MiningPost:DoRockletSpawn()
	if self.RockletSpawnTimer:IsPastSimMS(self.RockletSpawnInterval) and self.RockletsEnabled then
		local startx = self.DummyBombing:GetRandomPoint().X;
	
		for j = 1 , 3 do
			if MovableMan:GetMOIDCount() <= self.MOIDLimit then
				print("Spawn rocklet");				
				-- Add kamikadze rocklet
				local ship = CreateACRocket("Rocklet","Dummy.rte");
				ship:AddInventoryItem(CreateTDExplosive("Standard Bomb","Coalition.rte"));
				ship:AddInventoryItem(CreateTDExplosive("Standard Bomb","Coalition.rte"));

				ship.Team = self.RogueTeam;
				ship:SetControllerMode(Controller.CIM_AI, -1);
				ship.Pos = Vector(startx - j * 150, 0);
				ship.RotAngle = math.rad(180);
				ship.Vel = Vector(0 , 5 + math.random(25));

				MovableMan:AddActor(ship);
				self.RockletSpawnTimer:Reset();
				print("Rocklet spawn complete");				
			end
		end -- for
	end
end
-----------------------------------------------------------------------------------------
-- Spawn controlled bomber ship
-----------------------------------------------------------------------------------------
function MiningPost:DoControlledShipSpawn()
	if self.BomberSpawnTimer:IsPastSimMS(self.BomberSpawnInterval) and self.DropshipSpawnTimer:IsPastSimMS(self.DropshipSpawnInterval / 4) and MovableMan:GetMOIDCount() <= self.MOIDLimit and self.BombersEnabled then
		if not MovableMan:IsActor(self.ControlledShip) then
			-- Add bomber ship
			print("Spawn controlled ship");				
			
			self.ControlledShip = CreateACDropShip("Drop Ship MK1","Base.rte");
			self.LastAcceleration = Vector(0 , 0);
			self.ShipPath = self.Left2RightPath;
			self.CurrentWaypoint = 1;
			self.ControlledShip.Pos = self.ShipPath[self.CurrentWaypoint];
			self.ControlledShip.Team = self.CPUTeam;

			-- Load bombz
			for i = 1 , 12 do
				self.ControlledShip:AddInventoryItem(CreateTDExplosive("Standard Bomb","Coalition.rte"));
			end
			
			MovableMan:AddActor(self.ControlledShip);
			self.BomberSpawnTimer:Reset();
			print("Controlled ship spawn complete");
		end
	end
end
-----------------------------------------------------------------------------------------
-- Operate controlled ship
-----------------------------------------------------------------------------------------
function MiningPost:DoControlShip()
	if self.ControlledShip ~= nil then
		if MovableMan:IsActor(self.ControlledShip) then
			-- Calculate distance
			local avgx = self.ShipPath[self.CurrentWaypoint].X - self.ControlledShip.Pos.X;
			local avgy = self.ShipPath[self.CurrentWaypoint].Y - self.ControlledShip.Pos.Y;
			local dist = math.sqrt(avgx ^ 2 + avgy ^ 2);

			-- Start dropping bombs only after the third waypoint. Anyway it does not work on this map
			if self.CurrentWaypoint > 3 then
				if self.ControlledShip:HasObject("Standard Bomb") then
					self.ControlledShip:DropAllInventory();
				end
			end
			
			-- If we dont have any more bombs then fly away
			if not self.ControlledShip:HasObject("Standard Bomb") then
				self.ControlledShip:SetControllerMode(Controller.CIM_AI, -1);
				self.ControlledShip.Vel = self.ControlledShip.Vel + Vector(0 , -15);
				self.ControlledShip = nil;
			end

			if self.ControlledShip ~= nil then
				-- Check if we achieved checkpoint
				if dist < 50 then
					if self.CurrentWaypoint < #self.ShipPath then
						self.CurrentWaypoint = self.CurrentWaypoint + 1;
						-- self.ControlledShip:FlashWhite(250);
					else
						self.ControlledShip:SetControllerMode(Controller.CIM_AI, -1);
						self.ControlledShip.Vel = self.ControlledShip.Vel + Vector(0 , -15);
						self.ControlledShip = nil;
					end
				else
					-- Recalulate new velocitioes and push ship toward current waypoints
					local newvel = Vector((avgx / dist) * self.ControlledSpeed , (avgy / dist) * self.ControlledSpeed);
					self.ControlledShip.Vel = self.ControlledShip.Vel - Vector(self.LastVel.X * 0.99, self.LastVel.Y * 0.90);
					self.ControlledShip.Vel = self.ControlledShip.Vel + newvel;
					self.LastVel = newvel;
				end
			end
		end
	end
end
-----------------------------------------------------------------------------------------
-- Phase "No fight"
-----------------------------------------------------------------------------------------
function MiningPost:PhaseNoFight()
	-- Show team marks and special abilities
	if not self.GenericTimer:IsPastSimMS(60000) then
		if self.Mia ~= nil and MovableMan:IsActor(self.Mia) then
			self:AddObjectivePoint("Mia - Stealth", self.Mia.Pos + Vector(0 , -35), self.PlayerTeam, GameActivity.ARROWDOWN);
		end

		if self.Dimitri ~= nil and MovableMan:IsActor(self.Dimitri) then
			self:AddObjectivePoint("Dimitry - Sniper", self.Dimitri.Pos + Vector(0 , -35), self.PlayerTeam, GameActivity.ARROWDOWN);
		end

		if self.Brutus ~= nil and MovableMan:IsActor(self.Brutus) then
			self:AddObjectivePoint("Brutus - Heavy weapons", self.Brutus.Pos + Vector(0 , -35), self.PlayerTeam, GameActivity.ARROWDOWN);
		end

		if self.Sandra ~= nil and MovableMan:IsActor(self.Sandra) then
			self:AddObjectivePoint("Sandra - Medic", self.Sandra.Pos + Vector(0 , -35), self.PlayerTeam, GameActivity.ARROWDOWN);
		end

		if self.Gordon ~= nil and MovableMan:IsActor(self.Gordon) then
			self:AddObjectivePoint("Gordon - Explosives", self.Gordon.Pos + Vector(0 , -35), self.PlayerTeam, GameActivity.ARROWDOWN);
		end

		for player = 0, self.PlayerCount - 1 do
			if MovableMan:IsActor(self.AssignedBrains[player]) then
				self:AddObjectivePoint("Dafred - Commander - Best", self.AssignedBrains[player].Pos + Vector(0 , -35), self.PlayerTeam, GameActivity.ARROWDOWN);
			end
		end
	end
	
	-- Check sweep conditions
	if self.GenericTimer:IsPastSimMS(2500) then
		if not self.GenericTimer:IsPastSimMS(10000) then
			for player = 0, self.PlayerCount - 1 do
				self:ResetMessageTimer(player);
				FrameMan:ClearScreenText(player);
				FrameMan:SetScreenText("CAPTURE MINING BASE", player, 0, 5000, true);
			end
		end

		local liveenemies = 0;
		for actor in MovableMan.Actors do
			if actor.ClassName ~= "ADoor" and actor.Team == self.CPUTeam and self.SweepZone:IsInside(actor.Pos) then
				liveenemies = liveenemies + 1;
				
				if not self.GenericTimer:IsPastSimMS(10000) then
					self:AddObjectivePoint("Kill", actor.Pos + Vector(0 , -35), self.PlayerTeam, GameActivity.ARROWDOWN);
				end
			end
		end -- for
		
		if liveenemies == 0 then
			for player = 0, self.PlayerCount - 1 do
				if MovableMan:IsActor(self.AssignedBrains[player]) then
					if self.SweepZone:IsInside(self.AssignedBrains[player].Pos) then
						self:AdvanceToDigGold();
					end -- if
				end -- if
			end -- for
		end -- if
	end -- if

	-- For those who will never bring commander to the bunker to trigger next phase we will add
	if self.GenericTimer:IsPastSimMS(300000) then
		for player = 0, self.PlayerCount - 1 do
			self:ResetMessageTimer(player);
			FrameMan:ClearScreenText(player);
			FrameMan:SetScreenText("GET COMMANDER INSIDE THE BASE", player, 0, 5000, true);
		end
	end

	-- For those who will never bring commander to the bunker and dig gold add restriction
	if self:GetTeamFunds(self.PlayerTeam) > self.GoldToTriggerWarfare then
		self:AdvanceToWarfare();
	end
	
end -- func
-----------------------------------------------------------------------------------------
-- "No fight" -> "Dig gold"
-----------------------------------------------------------------------------------------
function MiningPost:AdvanceToDigGold()
	print("Camp captured");

	for player = 0, self.PlayerCount - 1 do
		self:ResetMessageTimer(player);
		FrameMan:ClearScreenText(player);
		FrameMan:SetScreenText(string.format("START MINING GOLD. WE NEED %d OZ", self.GoldToWin), player, 0, 10000, true);
	end

	self.GenericTimer:Reset();
	self.CurrentFightPhase = self.FightPhase.DIGGOLD;
end
-----------------------------------------------------------------------------------------
-- Phase "Dig Gold"
-----------------------------------------------------------------------------------------
function MiningPost:PhaseDigGold()
	for i = 1, #self.DigGoldMessages do
		if self.GenericTimer:IsPastSimMS(self.DigGoldMessageInterval * i) and self.DigGoldMessageShown[i] == false then
			self.DigGoldMessageShown[i] = true;
			
			for player = 0, self.PlayerCount - 1 do
				self:ResetMessageTimer(player);
				FrameMan:ClearScreenText(player);
				FrameMan:SetScreenText(self.DigGoldMessages[i], player, 0, self.DigGoldMessageShowTime, true);
			end			
		end
	end -- for
	
	if self.GenericTimer:IsPastSimMS(150000) then
		self:AdvanceToWarfare();
	end
end
-----------------------------------------------------------------------------------------
-- "Dig Gold" -> "Warfare"
-----------------------------------------------------------------------------------------
function MiningPost:AdvanceToWarfare()
	print("Warfare 1");

	for player = 0, self.PlayerCount - 1 do
		self:ResetMessageTimer(player);
		FrameMan:ClearScreenText(player);
		FrameMan:SetScreenText("COALITION TROOPS APPROACHING FROM THE WEST", player, 1000, 8000, true);
	end

	self.GenericTimer:Reset();
	self.CurrentFightPhase = self.FightPhase.WARFARE;

	-- Make quick spawn to simulate large initial forces goung to fight
	-- we'll change this a little bit later in phase processing
	self.DummySpawnInterval = 2000;
	self.CoalitionSpawnInterval = 2000;

	self.CoalitionSpawnTimer:Reset();
	self.DummySpawnTimer:Reset();
end
-----------------------------------------------------------------------------------------
-- Phase "Warfare"
-----------------------------------------------------------------------------------------
function MiningPost:PhaseWarfare()
	for i = 1, #self.WarfareMessages do
		if self.GenericTimer:IsPastSimMS(self.WarfareMessageInterval * i) and self.WarfareMessageShown[i] == false then
			self.WarfareMessageShown[i] = true;
			
			for player = 0, self.PlayerCount - 1 do
				self:ResetMessageTimer(player);
				FrameMan:ClearScreenText(player);
				FrameMan:SetScreenText(self.WarfareMessages[i], player, 0, self.WarfareMessageShowTime, true);
			end			
		end
	end -- for

	if self.CoalitionSpawnTimer:IsPastSimMS(self.CoalitionSpawnInterval) then
		self:SpawnClone(self.WeaponSets.Light);
		self.CoalitionSpawnTimer:Reset();
	end

	if self.DummySpawnTimer:IsPastSimMS(self.DummySpawnInterval) then
		self:SpawnDummy(self.WeaponSets.Light);
		self.DummySpawnTimer:Reset();
	end
	
	if self:GetTeamFunds(self.PlayerTeam) > self.GoldToPhase2 then
		self:AdvanceToWarfare2();
	end
	
	-- Initial masses spawned, now set normal spawn rates
	if	self.GenericTimer:IsPastSimMS(14000) then
		self.DummySpawnInterval = 18000 * self.DifficultyCoeff;
		self.CoalitionSpawnInterval = 14000 * self.DifficultyCoeff;
	end
end
-----------------------------------------------------------------------------------------
-- "Warfare" -> "Warfare 2"
-----------------------------------------------------------------------------------------
function MiningPost:AdvanceToWarfare2()
	print("Warfare 2");

	for player = 0, self.PlayerCount - 1 do
		self:ResetMessageTimer(player);
		FrameMan:ClearScreenText(player);
		FrameMan:SetScreenText("DROPSHIPS APPROACHING", player, 1000, 12000, true);
	end

	self.GenericTimer:Reset();
	self.CurrentFightPhase = self.FightPhase.WARFARE2;

	-- Reset dropship timer to avoid dropship and bomber to spawn at the same time
	self.DropshipSpawnTimer:Reset();

	self.BomberSpawnInterval = 45000 * self.DifficultyCoeff;
	self.DropshipSpawnInterval = 30000 * self.DifficultyCoeff;
	self.DummySpawnInterval = 12000 * self.DifficultyCoeff;
	self.CoalitionSpawnInterval = 12000 * self.DifficultyCoeff;

	self.BombersEnabled = true;
	self.DropshipsEnabled = true;
end
-----------------------------------------------------------------------------------------
-- Phase "Warfare 2"
-----------------------------------------------------------------------------------------
function MiningPost:PhaseWarfare2()
	if self.CoalitionSpawnTimer:IsPastSimMS(self.CoalitionSpawnInterval) then
		self:SpawnClone(self.WeaponSets.Heavy);
		self.CoalitionSpawnTimer:Reset();
	end

	if self.DummySpawnTimer:IsPastSimMS(self.DummySpawnInterval) then
		self:SpawnDummy(self.WeaponSets.Heavy);
		self.DummySpawnTimer:Reset();
	end
	
	if self:GetTeamFunds(self.PlayerTeam) > self.GoldToPhase3 then
		self:AdvanceToWarfare3();
	end
end
-----------------------------------------------------------------------------------------
-- "Warfare2" -> "Warfare 3"
-----------------------------------------------------------------------------------------
function MiningPost:AdvanceToWarfare3()
	print("Warfare 3");

	for player = 0, self.PlayerCount - 1 do
		self:ResetMessageTimer(player);
		FrameMan:ClearScreenText(player);
		FrameMan:SetScreenText("COLLECT AND SELL EXPENSIVE EXPERIMENTAL WEAPONS AND DUMMY AI CHIPS", player, 1000, 12000, true);
	end

	self.GenericTimer:Reset();
	self.CurrentFightPhase = self.FightPhase.WARFARE3;

	self.BomberSpawnInterval = 40000 * self.DifficultyCoeff;
	self.DropshipSpawnInterval = 25000 * self.DifficultyCoeff;
	self.RockletSpawnInterval = 35000 * self.DifficultyCoeff;
	self.DummySpawnInterval = 10000 * self.DifficultyCoeff;
	self.CoalitionSpawnInterval = 10000 * self.DifficultyCoeff;

	self.BombersEnabled = true;
	self.RockletsEnabled = true;
	self.DropshipsEnabled = true;
end
-----------------------------------------------------------------------------------------
-- Phase "Warfare 3"
-----------------------------------------------------------------------------------------
function MiningPost:PhaseWarfare3()
	if self.CoalitionSpawnTimer:IsPastSimMS(self.CoalitionSpawnInterval) then
		self:SpawnClone(self.WeaponSets.Extreme);
		self.CoalitionSpawnTimer:Reset();
	end

	if self.DummySpawnTimer:IsPastSimMS(self.DummySpawnInterval) then
		self:SpawnDummy(self.WeaponSets.Extreme);
		self.DummySpawnTimer:Reset();
	end
	
	if self:GetTeamFunds(self.PlayerTeam) >= self.GoldToWin then
		self:AdvanceToEvacuate();
	end
end
-----------------------------------------------------------------------------------------
-- "Warfare3" -> "Evacuate"
-----------------------------------------------------------------------------------------
function MiningPost:AdvanceToEvacuate()
	print("Evacuate");

	for player = 0, self.PlayerCount - 1 do
		self:ResetMessageTimer(player);
		FrameMan:ClearScreenText(player);
		FrameMan:SetScreenText("WE'VE GOT ENOUGH MONEY, EVACUATE", player, 1000, 12000, true);
	end

	self.GenericTimer:Reset();
	self.CurrentFightPhase = self.FightPhase.EVACUATE;

	self.BomberSpawnInterval = 30000 * self.DifficultyCoeff;
	self.DropshipSpawnInterval = 15000 * self.DifficultyCoeff;
	self.RockletSpawnInterval = 25000 * self.DifficultyCoeff;
	self.DummySpawnInterval = 6000 * self.DifficultyCoeff;
	self.CoalitionSpawnInterval = 6000 * self.DifficultyCoeff;

	self.BombersEnabled = true;
	self.RockletsEnabled = true;
	self.DropshipsEnabled = true;
end
-----------------------------------------------------------------------------------------
-- "Evacuate" -> "Warfare 3"
-----------------------------------------------------------------------------------------
function MiningPost:DegradeToWarfare3()
	print("Back ro warfare 3");

	for player = 0, self.PlayerCount - 1 do
		self:ResetMessageTimer(player);
		FrameMan:ClearScreenText(player);
		FrameMan:SetScreenText(string.format("WE NEED %d OZ. EVACUATE ABORTED !!!", self.GoldToWin), player, 1000, 10000, true);
	end

	self.GenericTimer:Reset();
	self.CurrentFightPhase = self.FightPhase.WARFARE3;

	self.BomberSpawnInterval = 40000 * self.DifficultyCoeff;
	self.DropshipSpawnInterval = 28000 * self.DifficultyCoeff;
	self.RockletSpawnInterval = 35000 * self.DifficultyCoeff;
	self.DummySpawnInterval = 10000 * self.DifficultyCoeff;
	self.CoalitionSpawnInterval = 10000 * self.DifficultyCoeff;

	self.BombersEnabled = true;
	self.RockletsEnabled = true;
	self.DropshipsEnabled = true;
end
-----------------------------------------------------------------------------------------
-- Phase "Evacuate"
-----------------------------------------------------------------------------------------
function MiningPost:PhaseEvacuate()
	if self.CoalitionSpawnTimer:IsPastSimMS(self.CoalitionSpawnInterval) then
		self:SpawnClone(self.WeaponSets.Extreme);
		self.CoalitionSpawnTimer:Reset();
	end

	if self.DummySpawnTimer:IsPastSimMS(self.DummySpawnInterval) then
		self:SpawnDummy(self.WeaponSets.Extreme);
		self.DummySpawnTimer:Reset();
	end

	if self:GetTeamFunds(self.PlayerTeam) < self.GoldToWin then
		self:DegradeToWarfare3();
	end
	
	self:AddObjectivePoint("EVACUATE", Vector(1000, 1), Activity.TEAM_1, GameActivity.ARROWUP);
	self:AddObjectivePoint("EVACUATE", Vector(2000, 1), Activity.TEAM_1, GameActivity.ARROWUP);
	self:AddObjectivePoint("EVACUATE", Vector(3000, 1), Activity.TEAM_1, GameActivity.ARROWUP);
end
-----------------------------------------------------------------------------------------
-- Spawn coalition trooper
-----------------------------------------------------------------------------------------
function MiningPost:SpawnClone(weaponset)
	if MovableMan:GetMOIDCount() <= self.MOIDLimit then
		local actor = nil;
		
		if weaponset == self.WeaponSets.Extreme and math.random() < 0.15 then
			actor = CreateAHuman("Soldier Heavy" , "Coalition.rte");
			actor:AddInventoryItem(CreateHDFirearm("Experimental Laser Rifle X-27" , "Mining Post.rte"));
			actor:AddInventoryItem(CreateHDFirearm(self.CoalitionSecondaryWeapons[math.random(#self.CoalitionSecondaryWeapons)],"Coalition.rte"));
		else
			if weaponset == self.WeaponSets.Light then
				actor = CreateAHuman("Soldier Light");
			else
				actor = CreateAHuman("Soldier Heavy");
			end
			
			if weaponset == self.WeaponSets.Light then
				actor:AddInventoryItem(CreateHDFirearm(self.CoalitionLightWeapons[math.random(#self.CoalitionLightWeapons)],"Coalition.rte"));
			elseif weaponset == self.WeaponSets.Heavy then
				actor:AddInventoryItem(CreateHDFirearm(self.CoalitionHeavyWeapons[math.random(#self.CoalitionHeavyWeapons)],"Coalition.rte"));
			elseif weaponset == self.WeaponSets.Extreme then
				actor:AddInventoryItem(CreateHDFirearm(self.CoalitionExtremeWeapons[math.random(#self.CoalitionExtremeWeapons)],"Coalition.rte"));
			end
			actor:AddInventoryItem(CreateHDFirearm(self.CoalitionSecondaryWeapons[math.random(#self.CoalitionSecondaryWeapons)],"Coalition.rte"));
		end

		actor.Team = self.CPUTeam;
		actor.AIMode = Actor.AIMODE_GOTO;
		actor:ClearAIWaypoints();
		actor:AddAISceneWaypoint(Vector(3990 , 744));
		actor.Pos = Vector(10 , 744);
		MovableMan:AddActor(actor);
	end
end
-----------------------------------------------------------------------------------------
-- Spawn dummy trooper
-----------------------------------------------------------------------------------------
function MiningPost:SpawnDummy(weaponset)
	if MovableMan:GetMOIDCount() <= self.MOIDLimit then
		local actor = nil;
		
		if weaponset == self.WeaponSets.Extreme and math.random() < 0.05 then
			actor = CreateAHuman("Mining Post Dummy Walking Controller" , "Mining Post.rte");
			actor:AddInventoryItem(CreateHDFirearm("Dummy Blaster MK3" , "Mining Post.rte"));
			actor:AddInventoryItem(CreateHDFirearm("Dummy Blaster MK3" , "Mining Post.rte"));
			actor:AddInventoryItem(CreateHeldDevice("Dummy AI Chip" , "Mining Post.rte"));
		else
			actor = CreateAHuman("Dummy");
			if weaponset == self.WeaponSets.Light then
				actor:AddInventoryItem(CreateHDFirearm(self.DummyLightWeapons[math.random(#self.DummyLightWeapons)],"Dummy.rte"));
			elseif weaponset == self.WeaponSets.Heavy then
				actor:AddInventoryItem(CreateHDFirearm(self.DummyHeavyWeapons[math.random(#self.DummyHeavyWeapons)],"Dummy.rte"));
			elseif weaponset == self.WeaponSets.Extreme then
				actor:AddInventoryItem(CreateHDFirearm(self.DummyExtremeWeapons[math.random(#self.DummyExtremeWeapons)],"Dummy.rte"));
			end
			actor:AddInventoryItem(CreateHDFirearm(self.DummySecondaryWeapons[math.random(#self.DummySecondaryWeapons)],"Dummy.rte"));
		end

		actor.Team = self.RogueTeam;
		actor.AIMode = Actor.AIMODE_GOTO;
		actor:ClearAIWaypoints();
		actor:AddAISceneWaypoint(Vector(10 , 744));
		actor.Pos = Vector(3990 , 744);
		MovableMan:AddActor(actor);
	end
end
-----------------------------------------------------------------------------------------
-- Enter orbit, check winning conditions
-----------------------------------------------------------------------------------------
function MiningPost:CraftEnteredOrbit()
	--If a craft leaves with the brain robot...
	if self.OrbitedCraft:HasObject("Dafred Brain") then
		if self.CurrentFightPhase == self.FightPhase.EVACUATE then
			-- Team 1 wins!
			self.WinnerTeam = Activity.TEAM_1;
			ActivityMan:EndActivity();
			-- Tell the script to stop running for brains as the game has ended.
			for player = 0, self.PlayerCount - 1 do
				self.braindead[player] = true;
			end
		else
			for player = 0, self.PlayerCount - 1 do
				self:ResetMessageTimer(player);
				FrameMan:ClearScreenText(player);
				FrameMan:SetScreenText("Coward!!!", player, 1500, 10000, true);
			end
		end
	end
end
-----------------------------------------------------------------------------------------
-- That's all folks!
-----------------------------------------------------------------------------------------








































